import { ImageProcessor } from './imageProcessor.js';
import path from 'path';

async function main() {
  try {
    const outputDir = path.join(process.cwd(), 'output');
    const processor = new ImageProcessor();
    const imageUrl = 'https://taoya.art/avatar.jpeg';

    // 使用 OTSU 方法处理
    console.log('使用 OTSU 方法处理图片:', imageUrl);
    const otsuResult = await processor.processImage(imageUrl, outputDir, 'otsu');
    console.log('\nOTSU 处理结果:');
    console.log(`图片尺寸: ${otsuResult.dimensions.width}x${otsuResult.dimensions.height}`);
    console.log(`OTSU 阈值: ${otsuResult.threshold}`);
    console.log(`图片输出路径: ${otsuResult.outputPath}`);
    console.log(`TSPL 指令输出路径: ${otsuResult.tsplPath}`);

    // 使用平均灰度方法处理
    console.log('\n使用平均灰度方法处理图片:', imageUrl);
    const avgResult = await processor.processImage(imageUrl, outputDir, 'average');
    console.log('\n平均灰度处理结果:');
    console.log(`图片尺寸: ${avgResult.dimensions.width}x${avgResult.dimensions.height}`);
    console.log(`平均灰度阈值: ${avgResult.threshold}`);
    console.log(`图片输出路径: ${avgResult.outputPath}`);
    console.log(`TSPL 指令输出路径: ${avgResult.tsplPath}`);

  } catch (error) {
    console.error('程序执行失败:', error.message);
  }
}

main();